@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 from numpy import fromfile
 from schema import Schema, Optional, Or
 import yaml
@@ -20,6 +20,9 @@ class Options(Enum):
     CHANNEL = "channel"
     PINS = "pins"
     RESTART_SECONDS = "restart_seconds"
+    CHUNK_SIZE = "chunk_size"
+    SPEAKER = "speaker"
+    MICROPHONE = "microphone"
 
 class PinConfig(Enum):
     ACTION_TOOGLE_TRANSMIT = "toggle_transmit"
@@ -48,9 +51,13 @@ CONFIG_SCHEMA = Schema({
     Optional(Options.SEND_BUFFER_LATENCY.value): float,
     Optional(Options.PINS.value): {str: PIN_SCHEMA},
     Optional(Options.RESTART_SECONDS.value): int,
+    Optional(Options.CHUNK_SIZE.value): int,
+    Optional(Options.SPEAKER.value): Or(int, str),
+    Optional(Options.MICROPHONE.value): Or(int, str),
 })
 
 DEFAULTS = {
+    Options.SERVER: "unused",
     Options.NICKNAME: "intercom_" + hex(uuid.getnode())[-4:],
     Options.PORT: 64738,
     Options.PASSWORD: "",
@@ -61,11 +68,14 @@ DEFAULTS = {
     Options.TOKENS: [],
     Options.PINS: {},
     Options.RESTART_SECONDS: 0,
+    Options.CHUNK_SIZE: 512,
+    Options.SPEAKER: "default",
+    Options.MICROPHONE: "default",
 }
 
 
 class Config:
-    def __init__(self, server: str = None, port: int = None, nickname: str = None, password:str = None, cert_file: str = None, key_file: str = None, channel: str = None, send_buffer_latency:float = None, tokens: List[str] = None, pins: Dict[str, PinConfig] = None, restart_seconds:int=None):
+    def __init__(self, server: str = None, port: int = None, nickname: str = None, password:str = None, cert_file: str = None, key_file: str = None, channel: str = None, send_buffer_latency:float = None, tokens: List[str] = None, pins: Dict[str, PinConfig] = None, restart_seconds:int=None, chunk_size: int=None, speaker:Union[str, int]=None, microphone:Union[str, int]=None):
         self._server = server if server is not None else DEFAULTS[Options.SERVER]
         self._port = port if port is not None else DEFAULTS[Options.PORT]
         self._nickname = nickname if nickname is not None else DEFAULTS[Options.NICKNAME]
@@ -77,6 +87,9 @@ class Config:
         self._tokens = tokens if tokens is not None else DEFAULTS[Options.TOKENS]
         self._pins = pins if pins is not None else DEFAULTS[Options.PINS]
         self._restart_seconds = restart_seconds if restart_seconds is not None else DEFAULTS[Options.RESTART_SECONDS]
+        self._chunk_size = chunk_size if chunk_size is not None else DEFAULTS[Options.CHUNK_SIZE]
+        self._microphone = microphone if microphone is not None else DEFAULTS[Options.MICROPHONE]
+        self._speaker = speaker if speaker is not None else DEFAULTS[Options.SPEAKER]
 
     @classmethod
     def fromFile(cls, path):
@@ -128,6 +141,18 @@ class Config:
     def restart_seconds(self) -> int:
         return self._restart_seconds
 
+    @property
+    def chunk_size(self) -> int:
+        return self._chunk_size
+
+    @property
+    def microphone(self) -> Union[str, int]:
+        return self._microphone
+        
+    @property
+    def speaker(self) -> Union[str, int]:
+        return self._speaker
+
     @classmethod
     def fromArgs(cls):
         parser = argparse.ArgumentParser()
@@ -152,8 +177,13 @@ class Config:
         parser.add_argument("--tokens", required=False, nargs="*",
                             help="One or more access tokens to be passed to the server", default=None)
         parser.add_argument("--restart_seconds", required=False, nargs="*",
-                            help="If set, how often the client should restar istelf in seconds.", default=None)
-
+                            help="If set, how often the client should restart istelf in seconds.", default=None)
+        parser.add_argument("--speaker", required=False, nargs="*",
+                            help="The speaker device to use for sound output.  Can be either the ALSA device name (a string) or a device index (an integer)", default=None)
+        parser.add_argument("--microphone", required=False, nargs="*",
+                            help="The microphone device to use for sound input.  Can be either the ALSA device name (a string) or a device index (an integer)", default=None)
+        parser.add_argument("--chunk_size", required=False, nargs="*",
+                            help="Size of the chunk in bytes that speaker or microphone output/input is processed.  Must be a power of 2.", default=None)
         args = parser.parse_args()
 
         if args.config is not None:
@@ -170,7 +200,10 @@ class Config:
                             send_buffer_latency=config.get(Options.SEND_BUFFER_LATENCY.value),
                             pins=config.get(Options.PINS.value), 
                             tokens=config.get(Options.TOKENS.value),
-                            restart_seconds=config.get(Options.RESTART_SECONDS.value))
+                            restart_seconds=config.get(Options.RESTART_SECONDS.value),
+                            chunk_size=config.get(Options.CHUNK_SIZE.value),
+                            microphone=config.get(Options.MICROPHONE.value),
+                            speaker=config.get(Options.SPEAKER.value))
         else:
             return Config(server=args.server, 
                 port=args.port, 
@@ -181,7 +214,10 @@ class Config:
                 channel=args.channel, 
                 send_buffer_latency=args.send_buffer_latency,
                 tokens=args.tokens,
-                restart_seconds=args.restart_seconds,)
+                restart_seconds=args.restart_seconds,
+                chunk_size=args.chunk_size,
+                microphone=args.microphone,
+                speaker=args.speaker)
 
     def get(self, key):
         if key in self.data:
